Authors and Contributors
========================

The following persons contributed to the development of the |MESSAGEix| framework:

- Daniel Huppmann, [@danielhuppmann](https://github.com/danielhuppmann), [iiasa](http://www.iiasa.ac.at/staff/huppmann)
- Matthew Gidden, [@gidden](https://github.com/gidden), [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=gidden), [web](mattgidden.com)
- Volker Krey, [@volker-krey](https://github.com/volker-krey), [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=krey)
- Oliver Fricko, [@OFR-IIASA](https://github.com/OFR-IIASA)
- Peter Kolp, [@peterkolp](https://github.com/peterkolp/), [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=kolp)
- Clara Orthofer, [@claraluisa](https://github.com/ClaraLuisa)
- Michael Pimmer, [@fonfon](https://github.com/fonfon), [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=pimmer)
- Adriano Vinca, [@adrivinca](https://github.com/adrivinca), [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=vinca)
- Alessio Mastrucci, [@amastrucci](https://github.com/amastrucci), [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=mastrucc)
- Miguel Poblete-Cazenave, [@MiguelPobleteCazenave](https://github.com/MiguelPobleteCazenave), [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=poblete)
- Thomas Zipperle, [@tzipperle](https://github.com/tzipperle)
- Behnam Zakeri, [@behnam2015](https://github.com/behnam2015)
  [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=zakeri)
- Nikolay Kushin, [@zikolach](https://github.com/zikolach)
  [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=kushin)
- Paul Natsuo Kishimoto, [@khaeru](https://github.com/khaeru)
  [web](https://paul.kishimoto.name)
